@@ -1,10 +1,10 @@
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(trackr)
 
 lb = setRefClass("BasicListBackend", fields = list(dat = "list"))
 BasicListBackend = function() lb$new()
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 setMethod("insert_record", c( target = "BasicListBackend"),
 function(object, id, target, opts, verbose = FALSE) {
     target$dat[[id]] = object
@@ -18,11 +18,11 @@ function(object, target, opts, verbose = FALSE) {
     invisible(target)
 })
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 setMethod("trackr_write", c(target = "BasicListBackend"), 
 function(target, opts, verbose = FALSE) target)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 setMethod("trackr_lookup", c("character", target = "BasicListBackend"),
 function(object, target, opts, exist = FALSE){
     found = which(object == names(target$dat))
@@ -32,7 +32,7 @@ function(object, target, opts, exist = FALSE){
         return(backend[[found]])
 })
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 setMethod("trackr_search", c(pattern = "character", target = "BasicListBackend"),
           function(pattern, target, opts, fields = NULL, ret_type = c("id", "list", "backend"),
@@ -45,30 +45,29 @@ setMethod("trackr_search", c(pattern = "character", target = "BasicListBackend")
     names(target$dat)[inds]
     })
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 
 library(ggplot2)
 plt = qplot(x = 1:10, y = rnorm(10))
 be = BasicListBackend()
-opts = TrackrOptions(img_dir = tempdir())
 db = TrackrDB(backend = be)
 defaultTDB(db)
 record(plt)
 findRecords("rnorm")
 
 
-## ----generateTags--------------------------------------------------------
+## ----generateTags-------------------------------------------------------------
 y = 5
 class(y) = "sillyclass"
 setMethod(generateTags, "sillyclass", function(object) "Hi vignette readers!")
 fs = makeFeatureSet(y)
 tags(fs)
 
-## ----FeatureSet_class----------------------------------------------------
+## ----FeatureSet_class---------------------------------------------------------
 setClass("AwesomeIntFeatureSet", contains = "ObjFeatureSet",
          slots = c(uniquevals = "integer"))
 
-## ----makeFeatureSet------------------------------------------------------
+## ----makeFeatureSet-----------------------------------------------------------
 setMethod("makeFeatureSet", "integer", function(object, ...) {
     innerobj = ObjFeatureSet(object, ...) 
     new("AwesomeIntFeatureSet", innerobj, uniquevals = unique(object))
